# -*- cmake -*-
#
# @file OpenRTMConfig.cmake
# @brief cmake-config file for OpenRTM-aist
# @author Noriaki Ando
# @date Fri Feb 13 13:55:46 UTC 2015
#
# This file is used for cmake config-mode.
# The following variables are defined.
#
# Basic compiler/linker options
# - OPENRTM_CFLAGS: cflags 
# - OPENRTM_INCLUDE_DIRS: include directories
# - OPENRTM_LDFLAGS: linker options
# - OPENRTM_LIBRARY_DIRS: library directories
# - OPENRTM_LIBRARIES: libraries
# - OPENRTM_LIB_DIR: OpenRTM's lib directory
#
# OpenRTM-aist specific directory
# - COIL_INCLUDE_DIR: coil include dir
# - OPENRTM_INCLUDE_DIR: OpenRTM's include directory
# - OPENRTM_LIB_DIR: OpenRTM's lib directory
# - OPENRTM_DATA_DIR: OpenRTM's shared directory
#
# OpenRTM-aist version
# - OPENRTM_VERSION: x.y.z version
# - OPENRTM_VERSION_MAJOR: major version number
# - OPENRTM_VERSION_MINOR: minor version number
# - OPENRTM_VERSION_PATCH: revision number
# - OPENRTM_SHORT_VERSION: short version number 1.1.0->110
#
# OpenRTM-aist's CORBA related settings
# - OPENRTM_ORB: CORBA implementation
# - OPENRTM_IDL_WRAPPER: rtm-skelwrapper command
# - OPENRTM_IDL_WRAPPER_FLAGS: rtm-skelwrapper flag
# - OPENRTM_IDLC: IDL command
# - OPENRTM_IDLFLAGS: IDL optins

message(STATUS "OpenRTMConfig.cmake found.")
message(STATUS "Configrued by configuration mode.")


# Basic compiler/linker options
set(OPENRTM_CFLAGS -Wall -fPIC -fstack-protector --param=ssp-buffer-size=4 -Wformat -Wformat-security -Werror=format-security -DNDEBUG -O2)
set(OPENRTM_INCLUDE_DIRS -I/opt/ros/hydro/include -I/opt/ros/hydro/include/coil-1.1 -I/opt/ros/hydro/include/openrtm-1.1 -I/opt/ros/hydro/include/openrtm-1.1/rtm/idl)
set(OPENRTM_LDFLAGS -luuid -ldl -export-dynamic)
set(OPENRTM_LIBRARY_DIRS -L/opt/ros/hydro/lib)
set(OPENRTM_LIBRARIES -lpthread  -lomniORB4 -lomnithread -lomniDynamic4 -lRTC -lcoil)
set(OPENRTM_LIB_DIR /opt/ros/hydro/lib/openrtm-1.1)

# OpenRTM-aist specific directory
set(COIL_INCLUDE_DIR /opt/ros/hydro/include/coil-1.1)
set(OPENRTM_INCLUDE_DIR /opt/ros/hydro/include/openrtm-1.1)
set(OPENRTM_LIB_DIR /opt/ros/hydro/lib/openrtm-1.1)
set(OPENRTM_DATA_DIR /opt/ros/hydro/share/openrtm-1.1)

# OpenRTM-aist version
set(OPENRTM_VERSION 1.1.0)
set(OPENRTM_VERSION_MAJOR 1)
set(OPENRTM_VERSION_MINOR 1)
set(OPENRTM_VERSION_PATCH 0)
set(OPENRTM_SHORT_VERSION 110)

# OpenRTM-aist's CORBA related settings
set(OPENRTM_ORB omniORB)
set(OPENRTM_IDL_WRAPPER rtm-skelwrapper)
set(OPENRTM_IDL_WRAPPER_FLAGS --include-dir= --skel-suffix=Skel --stub-suffix=Stub)
set(OPENRTM_IDLC /usr/bin/omniidl)
set(OPENRTM_IDLFLAGS -bcxx -Wba -nf)

message(STATUS "OpenRTM-aist configuration done")
# end of OpenRTMConfig.cmake
